BlockchainApi class

Constructors

BlockchainApi(RpcClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccount(ClientContext? ctx, GetAccountRequest request) Future<GetAccountResponse>
getBlock(ClientContext? ctx, GetBlockRequest request) Future<GetBlockResponse>
getBlockchainInfo(ClientContext? ctx, GetBlockchainInfoRequest request) Future<GetBlockchainInfoResponse>
getBlockHash(ClientContext? ctx, GetBlockHashRequest request) Future<GetBlockHashResponse>
getBlockHeight(ClientContext? ctx, GetBlockHeightRequest request) Future<GetBlockHeightResponse>
getConsensusInfo(ClientContext? ctx, GetConsensusInfoRequest request) Future<GetConsensusInfoResponse>
getPublicKey(ClientContext? ctx, GetPublicKeyRequest request) Future<GetPublicKeyResponse>
getTxPoolContent(ClientContext? ctx, GetTxPoolContentRequest request) Future<GetTxPoolContentResponse>
getValidator(ClientContext? ctx, GetValidatorRequest request) Future<GetValidatorResponse>
getValidatorAddresses(ClientContext? ctx, GetValidatorAddressesRequest request) Future<GetValidatorAddressesResponse>
getValidatorByNumber(ClientContext? ctx, GetValidatorByNumberRequest request) Future<GetValidatorResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited