PeerInfo class
Constructors
-
PeerInfo({int? status, String? moniker, String? agent, String? peerId, Iterable<String>? consensusKeys, Iterable<String>? consensusAddresses, int? services, String? lastBlockHash, int? height, Int64? lastSent, Int64? lastReceived, String? address, String? direction, Iterable<String>? protocols, int? totalSessions, int? completedSessions, MetricInfo? metricInfo})
-
factory
-
PeerInfo.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
-
factory
-
PeerInfo.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
-
factory
Methods
-
addExtension(Extension extension, Object? value)
→ void
-
Adds an extension field value to a repeated field.
inherited
-
check()
→ void
-
Throws a StateError if the message has required fields without a value.
inherited
-
clear()
→ void
-
Clears all data that was set in this message.
inherited
-
clearAddress()
→ void
-
-
clearAgent()
→ void
-
-
clearCompletedSessions()
→ void
-
-
clearDirection()
→ void
-
-
clearExtension(Extension extension)
→ void
-
Clears an extension field and also removes the extension.
inherited
-
clearField(int tagNumber)
→ void
-
Clears the contents of a given field.
inherited
-
clearHeight()
→ void
-
-
clearLastBlockHash()
→ void
-
-
clearLastReceived()
→ void
-
-
clearLastSent()
→ void
-
-
clearMetricInfo()
→ void
-
-
clearMoniker()
→ void
-
-
clearPeerId()
→ void
-
-
clearServices()
→ void
-
-
clearStatus()
→ void
-
-
clearTotalSessions()
→ void
-
-
clone()
→ PeerInfo
-
Creates a deep copy of the fields in this message.
(The generated code uses mergeFromMessage.)
-
copyWith(void updates(PeerInfo))
→ PeerInfo
-
Apply
updates to a copy of this message.
-
createEmptyInstance()
→ PeerInfo
-
Creates an empty instance of the same message type as this.
-
ensureMetricInfo()
→ MetricInfo
-
-
extensionsAreInitialized()
→ bool
-
inherited
-
freeze()
→ GeneratedMessage
-
Make this message read-only.
inherited
-
getDefaultForField(int tagNumber)
→ dynamic
-
Returns the default value for the given field.
inherited
-
getExtension(Extension extension)
→ dynamic
-
Returns the value of
extension.
inherited
-
getField(int tagNumber)
→ dynamic
-
Returns the value of the field associated with
tagNumber, or the
default value if it is not set.
inherited
-
getFieldOrNull(int tagNumber)
→ dynamic
-
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(String fieldName)
→ int?
-
inherited
-
hasAddress()
→ bool
-
-
hasAgent()
→ bool
-
-
hasCompletedSessions()
→ bool
-
-
hasDirection()
→ bool
-
-
hasExtension(Extension extension)
→ bool
-
Returns
true if a value of extension is present.
inherited
-
hasField(int tagNumber)
→ bool
-
Whether this message has a field associated with
tagNumber.
inherited
-
hasHeight()
→ bool
-
-
hasLastBlockHash()
→ bool
-
-
hasLastReceived()
→ bool
-
-
hasLastSent()
→ bool
-
-
hasMetricInfo()
→ bool
-
-
hasMoniker()
→ bool
-
-
hasPeerId()
→ bool
-
-
hasRequiredFields()
→ bool
-
Whether the message has required fields.
inherited
-
hasServices()
→ bool
-
-
hasStatus()
→ bool
-
-
hasTotalSessions()
→ bool
-
-
isInitialized()
→ bool
-
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
Same as
mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
Merges field values from
data, a JSON object, encoded as described by
GeneratedMessage.writeToJson.
inherited
-
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(GeneratedMessage other)
→ void
-
Merges the contents of the
other into this message.
inherited
-
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false})
→ void
-
Merges field values from
json, a JSON object using proto3 encoding.
inherited
-
mergeUnknownFields(UnknownFieldSet unknownFieldSet)
→ void
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setExtension(Extension extension, Object value)
→ void
-
Sets the value of a non-repeated extension field to
value.
inherited
-
setField(int tagNumber, Object value)
→ void
-
Sets the value of a field by its
tagNumber.
inherited
-
toBuilder()
→ GeneratedMessage
-
Creates a writable, shallow copy of this message.
inherited
-
toDebugString()
→ String
-
Returns a String representation of this message.
inherited
-
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()})
→ Object?
-
Returns an Object representing Proto3 JSON serialization of
this.
inherited
-
toString()
→ String
-
Returns a String representation of this message.
inherited
-
writeToBuffer()
→ Uint8List
-
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(CodedBufferWriter output)
→ void
-
Same as
writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson()
→ String
-
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap()
→ Map<String, dynamic>
-
Returns the JSON encoding of this message as a Dart Map.
inherited