TransactionApi class

Constructors

TransactionApi(RpcClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

broadcastTransaction(ClientContext? ctx, BroadcastTransactionRequest request) Future<BroadcastTransactionResponse>
calculateFee(ClientContext? ctx, CalculateFeeRequest request) Future<CalculateFeeResponse>
decodeRawTransaction(ClientContext? ctx, DecodeRawTransactionRequest request) Future<DecodeRawTransactionResponse>
getRawBondTransaction(ClientContext? ctx, GetRawBondTransactionRequest request) Future<GetRawTransactionResponse>
getRawTransferTransaction(ClientContext? ctx, GetRawTransferTransactionRequest request) Future<GetRawTransactionResponse>
getRawUnbondTransaction(ClientContext? ctx, GetRawUnbondTransactionRequest request) Future<GetRawTransactionResponse>
getRawWithdrawTransaction(ClientContext? ctx, GetRawWithdrawTransactionRequest request) Future<GetRawTransactionResponse>
getTransaction(ClientContext? ctx, GetTransactionRequest request) Future<GetTransactionResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited