TransactionServiceBase class abstract

Annotations
  • @GrpcServiceName.new('pactus.Transaction')

Constructors

TransactionServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
broadcastTransaction(ServiceCall call, BroadcastTransactionRequest request) Future<BroadcastTransactionResponse>
broadcastTransaction_Pre(ServiceCall call, Future<BroadcastTransactionRequest> request) Future<BroadcastTransactionResponse>
calculateFee(ServiceCall call, CalculateFeeRequest request) Future<CalculateFeeResponse>
calculateFee_Pre(ServiceCall call, Future<CalculateFeeRequest> request) Future<CalculateFeeResponse>
getRawBondTransaction(ServiceCall call, GetRawBondTransactionRequest request) Future<GetRawTransactionResponse>
getRawBondTransaction_Pre(ServiceCall call, Future<GetRawBondTransactionRequest> request) Future<GetRawTransactionResponse>
getRawTransferTransaction(ServiceCall call, GetRawTransferTransactionRequest request) Future<GetRawTransactionResponse>
getRawTransferTransaction_Pre(ServiceCall call, Future<GetRawTransferTransactionRequest> request) Future<GetRawTransactionResponse>
getRawUnbondTransaction(ServiceCall call, GetRawUnbondTransactionRequest request) Future<GetRawTransactionResponse>
getRawUnbondTransaction_Pre(ServiceCall call, Future<GetRawUnbondTransactionRequest> request) Future<GetRawTransactionResponse>
getRawWithdrawTransaction(ServiceCall call, GetRawWithdrawTransactionRequest request) Future<GetRawTransactionResponse>
getRawWithdrawTransaction_Pre(ServiceCall call, Future<GetRawWithdrawTransactionRequest> request) Future<GetRawTransactionResponse>
getTransaction(ServiceCall call, GetTransactionRequest request) Future<GetTransactionResponse>
getTransaction_Pre(ServiceCall call, Future<GetTransactionRequest> request) Future<GetTransactionResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited