UtilsApi class

Constructors

UtilsApi(RpcClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bLSPublicKeyAggregation(ClientContext? ctx, BLSPublicKeyAggregationRequest request) Future<BLSPublicKeyAggregationResponse>
bLSSignatureAggregation(ClientContext? ctx, BLSSignatureAggregationRequest request) Future<BLSSignatureAggregationResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signMessageWithPrivateKey(ClientContext? ctx, SignMessageWithPrivateKeyRequest request) Future<SignMessageWithPrivateKeyResponse>
toString() String
A string representation of this object.
inherited
verifyMessage(ClientContext? ctx, VerifyMessageRequest request) Future<VerifyMessageResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited