clone method

  1. @Deprecated('Using this can add significant overhead to your binary. ' 'Use [GeneratedMessageGenericExtensions.deepCopy] instead. ' 'Will be removed in next major version')
GetValidatorAddressRequest clone()

Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)

Implementation

@$core.Deprecated('Using this can add significant overhead to your binary. '
    'Use [GeneratedMessageGenericExtensions.deepCopy] instead. '
    'Will be removed in next major version')
GetValidatorAddressRequest clone() =>
    GetValidatorAddressRequest()..mergeFromMessage(this);