WalletClient class

Annotations
  • @GrpcServiceName.new('pactus.Wallet')

Constructors

WalletClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
createWallet(CreateWalletRequest request, {CallOptions? options}) → ResponseFuture<CreateWalletResponse>
getAddressHistory(GetAddressHistoryRequest request, {CallOptions? options}) → ResponseFuture<GetAddressHistoryResponse>
getNewAddress(GetNewAddressRequest request, {CallOptions? options}) → ResponseFuture<GetNewAddressResponse>
getTotalBalance(GetTotalBalanceRequest request, {CallOptions? options}) → ResponseFuture<GetTotalBalanceResponse>
getValidatorAddress(GetValidatorAddressRequest request, {CallOptions? options}) → ResponseFuture<GetValidatorAddressResponse>
loadWallet(LoadWalletRequest request, {CallOptions? options}) → ResponseFuture<LoadWalletResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restoreWallet(RestoreWalletRequest request, {CallOptions? options}) → ResponseFuture<RestoreWalletResponse>
signRawTransaction(SignRawTransactionRequest request, {CallOptions? options}) → ResponseFuture<SignRawTransactionResponse>
toString() String
A string representation of this object.
inherited
unloadWallet(UnloadWalletRequest request, {CallOptions? options}) → ResponseFuture<UnloadWalletResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited