BlockchainClient class
- Annotations
-
- @GrpcServiceName.new('pactus.Blockchain')
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ClientCall<Q, R>
-
inherited
-
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ResponseStream<R>
-
inherited
-
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options})
→ ResponseFuture<R>
-
inherited
-
getAccount(GetAccountRequest request, {CallOptions? options})
→ ResponseFuture<GetAccountResponse>
-
-
getBlock(GetBlockRequest request, {CallOptions? options})
→ ResponseFuture<GetBlockResponse>
-
-
getBlockchainInfo(GetBlockchainInfoRequest request, {CallOptions? options})
→ ResponseFuture<GetBlockchainInfoResponse>
-
-
getBlockHash(GetBlockHashRequest request, {CallOptions? options})
→ ResponseFuture<GetBlockHashResponse>
-
-
getBlockHeight(GetBlockHeightRequest request, {CallOptions? options})
→ ResponseFuture<GetBlockHeightResponse>
-
-
getConsensusInfo(GetConsensusInfoRequest request, {CallOptions? options})
→ ResponseFuture<GetConsensusInfoResponse>
-
-
getPublicKey(GetPublicKeyRequest request, {CallOptions? options})
→ ResponseFuture<GetPublicKeyResponse>
-
-
getValidator(GetValidatorRequest request, {CallOptions? options})
→ ResponseFuture<GetValidatorResponse>
-
-
getValidatorAddresses(GetValidatorAddressesRequest request, {CallOptions? options})
→ ResponseFuture<GetValidatorAddressesResponse>
-
-
getValidatorByNumber(GetValidatorByNumberRequest request, {CallOptions? options})
→ ResponseFuture<GetValidatorResponse>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited