- Annotations
-
- @GrpcServiceName.new('pactus.Blockchain')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
getAccount(ServiceCall call, GetAccountRequest request)
→ Future<GetAccountResponse>
-
-
getAccount_Pre(ServiceCall call, Future<GetAccountRequest> request)
→ Future<GetAccountResponse>
-
-
getBlock(ServiceCall call, GetBlockRequest request)
→ Future<GetBlockResponse>
-
-
getBlock_Pre(ServiceCall call, Future<GetBlockRequest> request)
→ Future<GetBlockResponse>
-
-
getBlockchainInfo(ServiceCall call, GetBlockchainInfoRequest request)
→ Future<GetBlockchainInfoResponse>
-
-
getBlockchainInfo_Pre(ServiceCall call, Future<GetBlockchainInfoRequest> request)
→ Future<GetBlockchainInfoResponse>
-
-
getBlockHash(ServiceCall call, GetBlockHashRequest request)
→ Future<GetBlockHashResponse>
-
-
getBlockHash_Pre(ServiceCall call, Future<GetBlockHashRequest> request)
→ Future<GetBlockHashResponse>
-
-
getBlockHeight(ServiceCall call, GetBlockHeightRequest request)
→ Future<GetBlockHeightResponse>
-
-
getBlockHeight_Pre(ServiceCall call, Future<GetBlockHeightRequest> request)
→ Future<GetBlockHeightResponse>
-
-
getConsensusInfo(ServiceCall call, GetConsensusInfoRequest request)
→ Future<GetConsensusInfoResponse>
-
-
getConsensusInfo_Pre(ServiceCall call, Future<GetConsensusInfoRequest> request)
→ Future<GetConsensusInfoResponse>
-
-
getPublicKey(ServiceCall call, GetPublicKeyRequest request)
→ Future<GetPublicKeyResponse>
-
-
getPublicKey_Pre(ServiceCall call, Future<GetPublicKeyRequest> request)
→ Future<GetPublicKeyResponse>
-
-
getValidator(ServiceCall call, GetValidatorRequest request)
→ Future<GetValidatorResponse>
-
-
getValidator_Pre(ServiceCall call, Future<GetValidatorRequest> request)
→ Future<GetValidatorResponse>
-
-
getValidatorAddresses(ServiceCall call, GetValidatorAddressesRequest request)
→ Future<GetValidatorAddressesResponse>
-
-
getValidatorAddresses_Pre(ServiceCall call, Future<GetValidatorAddressesRequest> request)
→ Future<GetValidatorAddressesResponse>
-
-
getValidatorByNumber(ServiceCall call, GetValidatorByNumberRequest request)
→ Future<GetValidatorResponse>
-
-
getValidatorByNumber_Pre(ServiceCall call, Future<GetValidatorByNumberRequest> request)
→ Future<GetValidatorResponse>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited