UtilsServiceBase class abstract
Constructors
Properties
Methods
-
bLSPublicKeyAggregation(
ServerContext ctx, BLSPublicKeyAggregationRequest request) → Future< BLSPublicKeyAggregationResponse> -
bLSSignatureAggregation(
ServerContext ctx, BLSSignatureAggregationRequest request) → Future< BLSSignatureAggregationResponse> -
createRequest(
String method) → GeneratedMessage - Creates a message object that can deserialize a request.
-
handleCall(
ServerContext ctx, String method, GeneratedMessage request) → Future< GeneratedMessage> - Dispatches the call. The request object should come from createRequest.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signMessageWithPrivateKey(
ServerContext ctx, SignMessageWithPrivateKeyRequest request) → Future< SignMessageWithPrivateKeyResponse> -
toString(
) → String -
A string representation of this object.
inherited
-
verifyMessage(
ServerContext ctx, VerifyMessageRequest request) → Future< VerifyMessageResponse>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited