- Annotations
-
- @GrpcServiceName.new('pactus.Wallet')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
createWallet(ServiceCall call, CreateWalletRequest request)
→ Future<CreateWalletResponse>
-
-
createWallet_Pre(ServiceCall call, Future<CreateWalletRequest> request)
→ Future<CreateWalletResponse>
-
-
getAddressHistory(ServiceCall call, GetAddressHistoryRequest request)
→ Future<GetAddressHistoryResponse>
-
-
getAddressHistory_Pre(ServiceCall call, Future<GetAddressHistoryRequest> request)
→ Future<GetAddressHistoryResponse>
-
-
getNewAddress(ServiceCall call, GetNewAddressRequest request)
→ Future<GetNewAddressResponse>
-
-
getNewAddress_Pre(ServiceCall call, Future<GetNewAddressRequest> request)
→ Future<GetNewAddressResponse>
-
-
getTotalBalance(ServiceCall call, GetTotalBalanceRequest request)
→ Future<GetTotalBalanceResponse>
-
-
getTotalBalance_Pre(ServiceCall call, Future<GetTotalBalanceRequest> request)
→ Future<GetTotalBalanceResponse>
-
-
getValidatorAddress(ServiceCall call, GetValidatorAddressRequest request)
→ Future<GetValidatorAddressResponse>
-
-
getValidatorAddress_Pre(ServiceCall call, Future<GetValidatorAddressRequest> request)
→ Future<GetValidatorAddressResponse>
-
-
loadWallet(ServiceCall call, LoadWalletRequest request)
→ Future<LoadWalletResponse>
-
-
loadWallet_Pre(ServiceCall call, Future<LoadWalletRequest> request)
→ Future<LoadWalletResponse>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
restoreWallet(ServiceCall call, RestoreWalletRequest request)
→ Future<RestoreWalletResponse>
-
-
restoreWallet_Pre(ServiceCall call, Future<RestoreWalletRequest> request)
→ Future<RestoreWalletResponse>
-
-
signRawTransaction(ServiceCall call, SignRawTransactionRequest request)
→ Future<SignRawTransactionResponse>
-
-
signRawTransaction_Pre(ServiceCall call, Future<SignRawTransactionRequest> request)
→ Future<SignRawTransactionResponse>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
unloadWallet(ServiceCall call, UnloadWalletRequest request)
→ Future<UnloadWalletResponse>
-
-
unloadWallet_Pre(ServiceCall call, Future<UnloadWalletRequest> request)
→ Future<UnloadWalletResponse>
-